@@ -44,7 +44,7 @@ public:
     QWidget *currentItem = nullptr;
     QToolButton *tabsClose = nullptr;
 
-    Q_REQUIRED_RESULT QWidget *selectedWidget() const
+    [[nodiscard]] QWidget *selectedWidget() const
     {
         return (currentItem && q->indexOf(currentItem) != -1) ? currentItem : q->currentWidget();
     }
@@ -486,9 +486,7 @@ void TabWidget::slotCloseRequest(int index)
 
 void TabWidget::slotActivateTab()
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    setCurrentIndex(sender()->objectName().rightRef(2).toInt() - 1);
-#else
     setCurrentIndex(QStringView(sender()->objectName()).right(2).toInt() - 1);
-#endif
 }
+
+#include "moc_tabwidget.cpp"
